@@ -18,6 +18,13 @@
 #'   airport in a given year and month
 #' }
 #' 
+#' The recommended approach to download data for many stations (airports)
+#' is to supply a vector of stations to the \code{station} argument rather than 
+#' iterating over many calls to \code{anyflights()}. The \code{faa} column
+#' in dataframes outputted by \code{get_airports()} provides the FAA LID
+#' codes for all supported airports. See 
+#' ?\code{\link{get_flights}} for more details on implementation.
+#' 
 #' @param station A character vector giving the origin US airports of interest
 #'  (as the FAA LID airport code).
 #'  
@@ -57,16 +64,43 @@
 #' @export
 anyflights <- function(station, year, month = 1:12, dir = NULL) {
   
+  # create a function, unique to this call to anyflights,
+  # that returns the difference in time from when the function was called
+  diff_from_start <- create_diff_from_start()
+  
+  # initiate the progress bar
+  pb <- progress::progress_bar$new(
+    format = ":what",
+    clear = FALSE, width = 60, show_after = 0)
+  pb$tick(0)
+  
+  pb$message(stringr::str_pad("Total Time Elapsed", 50, side = "left"))
+  
   if (!is.null(dir)) {
     dir.create(dir, recursive = TRUE, showWarnings = FALSE)
   }
   
-  flights <- get_flights(station, year, month, dir)
-  airlines <- get_airlines(dir, flights)
-  planes <- get_planes(year, dir, flights)
-  airports <- get_airports(dir)
-  weather <- get_weather(station, year, month, dir)
+  write_tick(pb, "  Processing Arguments...")
+  flights <- get_flights(station, year, month, dir, 
+                         pb = pb, diff_fn = diff_from_start)
+  write_message(pb, "Finished Downloading Flights Data", diff_from_start)
   
+  write_tick(pb, "  Downloading Airlines...")
+  airlines <- get_airlines(dir, flights)
+  write_message(pb, "Finished Downloading Airlines Data", diff_from_start)
+  
+  write_tick(pb, "  Downloading Planes...")
+  planes <- get_planes(year, dir, flights)
+  write_message(pb, "Finished Downloading Planes Data", diff_from_start)
+  
+  write_tick(pb, "  Downloading Airports...")
+  airports <- get_airports(dir)
+  write_message(pb, "Finished Downloading Airports Data", diff_from_start)
+  
+  write_tick(pb, "  Downloading Weather...")
+  weather <- get_weather(station, year, month, dir)
+  write_message(pb, "Finished Downloading Weather Data", diff_from_start)
+  write_tick(pb, "All Done!")
   return(list(airlines = airlines,
               airports = airports,
               flights = flights,
